==> haskell-hspec-wai-json-0.9.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-LkTs3467MAQGAs3oGQavbo
key: hspec-wai-json-0.9.2-LkTs3467MAQGAs3oGQavbo
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 4bfa1bd022bac491e0706624747be106
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-LkTs3467MAQGAs3oGQavbo
depends:
    aeson-1.4.2.0-3zTMwffMFEmL8PGGMXbXzR
    aeson-qq-0.8.2-IR49Q32ksqyA4Z75q7mTIk base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.2-4iKpGaZObFDFbyFVd9fzfE template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.2
id: hspec-wai-json-0.9.2-LrYJh4Bh5m2DjjhFEZdlUS
key: hspec-wai-json-0.9.2-LrYJh4Bh5m2DjjhFEZdlUS
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2018 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 7361275fc60ab4ed9bf651390f0f5df9
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hspec-wai-json-0.9.2
hs-libraries: HShspec-wai-json-0.9.2-LrYJh4Bh5m2DjjhFEZdlUS
depends:
    aeson-1.4.2.0-GJCiFec4f867wIRLCAWvTv
    aeson-qq-0.8.2-A6b9A8xW9P388TWTTy5WBQ base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.2-6zIr4pE87wAIVFOSa0kNIY template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
